var express = require("express");
var router = express.Router();

const config = require("config");

const CLIENT_ID = config.get("payments.paypal.testing.client_id");
const APP_SECRET = config.get("payments.paypal.testing.secret");
const base = "https://api-m.sandbox.paypal.com";

/* Client initiates payment */
router.post("/", async (req, res, next) => {
  // All Submitted data is verified at this point
  const order = await createOrder(req);
  res.json(order);
});

module.exports = router;

//////////////////////

// PayPal API helpers

//////////////////////

// use the orders api to create an order

async function createOrder(req) {
  const accessToken = await generateAccessToken();

  const url = `${base}/v2/checkout/orders`;

  let order = {
    intent: "CAPTURE",

    purchase_units: [
      {
        description: "MetaGer Pass Einkauf",
        amount: {
          currency_code: "EUR",
          value: req.body.price.toFixed(2),
        },
        items: [
          {
            name: "MetaGer Pass: Suchanfragen (100x)",
            quantity: 1,
            unit_amount: 0,
          },
        ],
      },
    ],
    application_context: {
      brand_name: "SUMA-EV",
      shipping_preference: "NO_SHIPPING",
    },
  };
  console.log(order.purchase_units[0].amount);

  const response = await fetch(url, {
    method: "post",

    headers: {
      "Content-Type": "application/json",
      Authorization: `Bearer ${accessToken}`,
    },

    body: JSON.stringify(order),
  });

  const data = await response.json();

  return data;
}

// use the orders api to capture payment for an order

async function capturePayment(orderId) {
  const accessToken = await generateAccessToken();

  const url = `${base}/v2/checkout/orders/${orderId}/capture`;

  const response = await fetch(url, {
    method: "post",

    headers: {
      "Content-Type": "application/json",

      Authorization: `Bearer ${accessToken}`,
    },
  });

  const data = await response.json();

  return data;
}

// generate an access token using client id and app secret

async function generateAccessToken() {
  const auth = Buffer.from(CLIENT_ID + ":" + APP_SECRET).toString("base64");

  const response = await fetch(`${base}/v1/oauth2/token`, {
    method: "post",

    body: "grant_type=client_credentials",

    headers: {
      Authorization: `Basic ${auth}`,
    },
  });

  const data = await response.json();

  return data.access_token;
}
